marktools.Mark
==============

.. inheritance-diagram:: abjad.tools.marktools.Mark.Mark.Mark
   :private-bases:

.. autoclass:: abjad.tools.marktools.Mark.Mark.Mark

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.Mark.Mark.Mark.start_component

Methods
-------

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.attach

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.detach

Special Methods
---------------

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__call__

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__delattr__

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__eq__

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__ne__

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__repr__

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__str__

   .. note:: Inherited from `__builtin__.object`
